@@ -6,5 +6,5 @@ class Tag:
         highrise_id,
         name
     ):
-        self.highrise_id = highrise_id
-        self.name = name
\ No newline at end of file
+        self.highrise_id = highrise_id.pyval
+        self.name = name.pyval
\ No newline at end of file
